[This page is still under development]
# IOHexperimenter : Test
We are using [Google Test](https://github.com/google/googletest) framework, please follow the instruction if you plan to contribute unittest for the project.

## Test Features

### bbob and pbo
* Testing the `evaluate` function of problem class returns expected result.
* Input and output are defined in *.in files.

### ecdf
* Testing the logger maintains data correctly and the `sum` function returns expected result.

### experiment
* Testing `configuration` acquires correct info from *.ini files.

### ToDo
* loggerInfo: returns correct info
* observer: returns correct flag
* suite: maintains problems info correctly
* csvlogger: write correct info
* problem: more input test.